const documentdb = require("documentdb");
const read = require("./read");
const deleteDocument = require("./delete");
const upsert = require("./upsert");

function create(endpoint, key, database, collection) {
  if (!endpoint) throw new Error("endpoint is required");
  if (!key) throw new Error("key is required");
  if (!database) throw new Error("database is required");
  if (!collection) throw new Error("collection is required");

  let client = new documentdb.DocumentClient(endpoint, { masterKey: key });

  let collectionUri = documentdb.UriFactory.createDocumentCollectionUri(database, collection);

  return {
    read: function (query) {
      return read(client, collectionUri, query);
    },
    delete: function (document) {
      return deleteDocument(client, document);
    },
    upsert: function (document) {
      return upsert(client, collectionUri, document);
    }
  };
}

module.exports = exports = create;
